"""
seatconnect - A Python 3 library for interacting with Seat Connect.

For more details and documentation, visit the github page at https://github.com/farfar/seatconnect
"""

from seatconnect.connection import Connection
